InputControllerState class

Inheritance

Properties

controller → ValueNotifier
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(FormDataValue newValue) → InputControllerState
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited