FixedListInputConfig class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.kebab, createToJson: false)

Constructors

FixedListInputConfig({required String id, required String label, String? defaultValue, bool? required, Conditions? conditions, required List<String> options, String? defaultOption, String? optionsSemanticLabel})
FixedListInputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

conditionEvalResult ↔ ConditionEvalResult?
getter/setter pairinherited
conditions → Conditions?
finalinherited
defaultOption → String?
final
defaultValue → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
isEnabled → bool
no setterinherited
isRequired → bool
no setterinherited
label → String
finalinherited
labelText → String
no setterinherited
maxLength ↔ int?
latefinal
onChanged ↔ InputChanged?
getter/setter pairinherited
options → List<String>
final
optionsSemanticLabel → String?
final
required → bool?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InputType
finalinherited
validators → List<ValidatorConfig>?
finalinherited

Methods

buildInputWidget(BuildContext context, InputChanged onChanged, Map<String, InputValue> values) → Widget
override
evaluateConditions({required Map<String, InputValue> values, InputChanged? onChanged}) → void
inherited
isValid(String? value) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited