InputConfig<T> class abstract

Implementers

Constructors

InputConfig({required InputType type, required String id, required String label, T? defaultValue, bool? required, Conditions? conditions, List<ValidatorConfig>? validators})

Properties

conditionEvalResult ↔ ConditionEvalResult?
getter/setter pair
conditions → Conditions?
final
defaultValue → T?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isEnabled → bool
no setter
isRequired → bool
no setter
label → String
final
labelText → String
no setter
onChanged ↔ InputChanged?
getter/setter pair
required → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InputType
final
validators → List<ValidatorConfig>?
final

Methods

buildInputWidget(BuildContext context, InputChanged onChanged, Map<String, InputValue> values) → Widget
evaluateConditions({required Map<String, InputValue> values, InputChanged? onChanged}) → void
isValid(String? value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited