NumberValidatorConfig class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.kebab, createToJson: false)

Constructors

NumberValidatorConfig({int? min, int? max})
const
NumberValidatorConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → int?
final
min → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ValidatorType
finalinherited

Methods

createValidator() → Validator
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited