AddressInput<T> class

Inheritance

Constructors

AddressInput({Key? key, AddressLabels<T> labels = const AddressLabels(), AddressValue<T> value = const AddressValue._(), bool enabled = true, bool showDescriptionField = false, bool showCountyField = false, bool showCountryField = false, Validator? postalCodeValidator, List<Country>? countryPriorityList, FocusCallback? onFocus, FocusNode? focusNode, required AddressInputCallback<T> onChanged})
const

Properties

countryPriorityList → List<Country>?
Country selection priority list
final
enabled → bool
Enable or disable the address input fields
final
focusNode → FocusNode?
The focus node for the AddressInput widget.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels → AddressLabels<T>
final
onChanged → AddressInputCallback<T>
Called when the address value changes.
final
onFocus → FocusCallback?
Called when the an address input field comes into focus.
final
postalCodeValidator → Validator?
Optional postal code validator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCountryField → bool
Optional country field
final
showCountyField → bool
Optional county field
final
showDescriptionField → bool
Optional address description field
final
value → AddressValue<T>
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AddressInput<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

calculateHeight({bool showTypesSelection = true, bool showDescriptionField = false, bool showCountyField = false, bool showCountryField = false}) → double
Helper to calculate the height of the AddressInput widget