AddressLabels<T> class

Constructors

AddressLabels({String? description, String? number, String? street, String? other, String? municipality, String? county, String? province, String? postalCode, String? countryCode, String? provincePickerSemanticLabel, String? countryPickerSemanticLabel, List<AddressTypeSelection<T>>? addressTypes, List<(String, String, Image?)>? provinceList})
const

Properties

addressTypes → List<AddressTypeSelection<T>>?
a list of possible address types
final
countryCode → String?
final
countryPickerSemanticLabel → String?
final
county → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
determines if all required labels are set
no setter
municipality → String?
final
number → String?
final
other → String?
final
postalCode → String?
final
province → String?
final
provinceList → List<(String, String, Image?)>?
provice or state list. (province code, province name, flag image)
final
provincePickerSemanticLabel → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
street → String?
final

Methods

copyWith({String? description, String? number, String? street, String? other, String? municipality, String? county, String? province, String? postalCode, String? countryCode, String? provincePickerSemanticLabel, String? countryPickerSemanticLabel, List<AddressTypeSelection<T>>? addressTypes, String? addressTypeTooltip, List<(String, String, Image?)>? provinceList}) → AddressLabels<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromLocalization<T>(BuildContext context, {String? countryCode = 'US'}) → AddressLabels<T>