ContactInput<T> class

Inheritance

Constructors

ContactInput({Key? key, ContactLabels<T> labels = const ContactLabels(), ContactValue<T> value = const ContactValue._(), bool enabled = true, bool showTypeSelectionField = true, bool showDescriptionField = false, bool showCountryForPhoneNumbers = true, bool enableCountrySelectionForPhoneNumbers = true, String defaultCountryCode = 'US', Validator? emailValidator, FocusCallback? onFocus, FocusNode? focusNode, required ContactInputCallback<T> onChanged})
const

Properties

defaultCountryCode → String
Default country code for phone numbers
final
emailValidator → Validator?
Optional validator for emails
final
enableCountrySelectionForPhoneNumbers → bool
Optional enable selecting the country
final
enabled → bool
Enable or disable the contact input fields
final
focusNode → FocusNode?
The focus node for the AddressInput widget.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels → ContactLabels<T>
final
onChanged → ContactInputCallback<T>
Called when the address value changes
final
onFocus → FocusCallback?
Called when the an address input field comes into focus.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCountryForPhoneNumbers → bool
Optional display the phone number country flag and international dial code
final
showDescriptionField → bool
Optional contact description field
final
showTypeSelectionField → bool
Optional contact type selection field
final
value → ContactValue<T>
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ContactInput<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

calculateHeight({required bool showDescriptionField, required bool showTypeSelectionField}) → double
Helper to calculate the height of the ContactInput widget