ContactLabels<T> class

Constructors

ContactLabels({String? type, String? description, String? emailAddress, String? phoneNumber, String? socialMediaHandle, List<ContactTypeSelection<T>>? contactTypes, String? contactTypeSemanticLabel})
const

Properties

contactTypes → List<ContactTypeSelection<T>>?
a list of possible contact types
final
contactTypeSemanticLabel → String?
final
description → String?
final
emailAddress → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
determines if all required labels are set
no setter
phoneNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socialMediaHandle → String?
final
type → String?
final

Methods

copyWith({String? type, String? description, String? emailAddress, String? phoneNumber, List<ContactTypeSelection<T>>? contactTypes, String? contactTypeSemanticLabel}) → ContactLabels<T>
getInputType(T? type) → ContactInputType
getTypeLabel(T? type) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromLocalization<T>(BuildContext context) → ContactLabels<T>