FormValue class abstract

A form value that can be used in a form to capture the a composite input value.

Implementers

Constructors

FormValue({Key? key})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
determines if all fields are empty
no setter
isNotEmpty → bool
determines if all fields are not empty
no setter
isReadOnly → bool
true if the form value is read only
no setter
isRequiredNotEmpty → bool
determines if all required fields are not empty
no setter
isValid → bool
determines if all required fields are valie
no setter
key → Key?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
validFields → Map<String, bool>
captures the validity of field data
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited