MultiInput<T extends FormValue> class

Inheritance

Constructors

MultiInput({Key? key, required List<T> values, required MultiInputBuilder<T> builder, required AddInputCallback onAdd, required RemoveInputCallback onRemove, bool enabled = true, bool groubBox = true, Color? groupBoxBackground, EdgeInsets groupBoxMargin = const EdgeInsets.all(8.0), EdgeInsets groupBoxPadding = const EdgeInsets.all(10.0), MainAxisAlignment groupBoxActionAlignment = MainAxisAlignment.end, EdgeInsets actionsPadding = const EdgeInsets.all(0.0), String? semanticLabelAddButton, String? semanticLabelDeleteButton})
const

Properties

actionsPadding → EdgeInsets
The padding of the action buttons when not within a group box
final
builder → MultiInputBuilder<T>
The builder function that will be called for each value in the list
final
enabled → bool
Enables or disables the multi
final
groubBox → bool
Encloses the input in a group box
final
groupBoxActionAlignment → MainAxisAlignment
The alignment of the action buttons when input is enclosed in a group box
final
groupBoxBackground → Color?
The background color of the multi- input. This needs to be set if the input is rendered in a dialog
final
groupBoxMargin → EdgeInsets
The margin of the group box enclosing a single input
final
groupBoxPadding → EdgeInsets
The padding of the group box enclosing a single input
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAdd → AddInputCallback
Called when the user adds a new address
final
onRemove → RemoveInputCallback
Called when the user removes an address
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabelAddButton → String?
Semantics label for the add button
final
semanticLabelDeleteButton → String?
Semantics label for the delete button
final
values → List<T>
The initial value of the multi-input list
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MultiInput<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited