TrailingIcon<T> class

Constructors

TrailingIcon({IconData? icon, Widget? iconWidget, Color? color, String? tooltip, ValueChanged<T>? onTap, VoidCallback? onTapVoid})
const

Properties

color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconWidget → Widget?
final
onTap → ValueChanged<T>?
Called with the value of the list item when tapped
final
onTapVoid → VoidCallback?
For backward compatibility: if provided, called with no arguments
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited