DropdownListItem class

Dropdown list item represents a menu item that will be displayed in the dropdown list.

Constructors

const

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconWidget → Widget?
final
id → String
final
label → String?
final
labelWidget → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited