TextInput class

Inheritance
Implementers

Constructors

TextInput({Key? key, String? labelText, String? initialValue, TextInputType? keyboardType, int? maxCharsInLine, int maxLines = 1, int? maxLength, bool hExpandable = false, bool vExpandable = false, List<DropdownListItem>? options, bool isOptionEditable = true, String? optionsSemanticLabel, bool isRequired = false, bool readOnly = false, bool enabled = true, bool fixedHeight = true, InputIcon? leadingIcon, InputIcon? trailingIcon, TextStyle? textStyle, Color? focusedBorderColor, FocusNode? focusNode, TextEditingController? controller, List<TextInputFormatter>? inputFormatters, Validator? validator, ValidatedValueChanged<String?>? onChanged, ValueChanged<String>? onEnter, EdgeInsets padding = const EdgeInsets.fromLTRB(8.0, 8.0, 8.0, 0.0)})
const

Properties

controller → TextEditingController?
final
enabled → bool
final
fixedHeight → bool
final
focusedBorderColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hExpandable → bool
final
initialValue → String?
final
inputFormatters → List<TextInputFormatter>?
final
isOptionEditable → bool
final
isRequired → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
labelText → String?
final
leadingIcon → InputIcon?
final
maxCharsInLine → int?
final
maxLength → int?
final
maxLines → int
final
onChanged → ValidatedValueChanged<String?>?
final
onEnter → ValueChanged<String>?
final
options → List<DropdownListItem>?
final
optionsSemanticLabel → String?
final
padding → EdgeInsets
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
final
trailingIcon → InputIcon?
final
validator → Validator?
final
vExpandable → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lookupLabelText(BuildContext context) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited