UsernameInput class

Inheritance

Constructors

UsernameInput({Key? key, String? labelText, String? initialValue, bool isRequired = false, bool enabled = true, IconData icon = Icons.person, Validator? validator, ValidatedValueChanged<String?>? onChanged, ValueChanged<String>? onEnter, EdgeInsets padding = const EdgeInsets.fromLTRB(8.0, 8.0, 8.0, 0.0)})

Properties

controller → TextEditingController?
finalinherited
enabled → bool
finalinherited
fixedHeight → bool
finalinherited
focusedBorderColor → Color?
finalinherited
focusNode → FocusNode?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hExpandable → bool
finalinherited
initialValue → String?
finalinherited
inputFormatters → List<TextInputFormatter>?
finalinherited
isOptionEditable → bool
finalinherited
isRequired → bool
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
finalinherited
labelText → String?
finalinherited
leadingIcon → InputIcon?
finalinherited
maxCharsInLine → int?
finalinherited
maxLength → int?
finalinherited
maxLines → int
finalinherited
onChanged → ValidatedValueChanged<String?>?
finalinherited
onEnter → ValueChanged<String>?
finalinherited
options → List<DropdownListItem>?
finalinherited
optionsSemanticLabel → String?
finalinherited
padding → EdgeInsets
finalinherited
readOnly → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
finalinherited
trailingIcon → InputIcon?
finalinherited
validator → Validator?
finalinherited
vExpandable → bool
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lookupLabelText(BuildContext context) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited