ButtonTool<T extends Equatable> class

Inheritance

Constructors

ButtonTool({Key? key, ToolVisibility visibility = ToolVisibility.floatOnCompact, ValueNotifier<T>? toolValue, Widget? icon(T? param) = _null<Widget>, IconData? iconData(T? param) = _null<IconData>, String? tooltip(T? param) = _null<String>, bool enabled(T? param) = _true, void onPressed(T? param)?, Size size = const Size(40, 40), Color? iconColor, Color? backgroundColor, Color? pressedIconColor, Color? pressedBackgroundColor, ButtonStyle? style, String? semanticLabel, bool isPressed(T? param)?})
const

Properties

alignment → Alignment?
no setterinherited
backgroundColor → Color?
final
enabled → bool Function(T? param)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
no setterinherited
hidden → bool Function(T? param)
finalinherited
icon → Widget? Function(T? param)
finalinherited
iconColor → Color?
final
iconData → IconData? Function(T? param)
finalinherited
isPressed → bool Function(T? param)?
final
key → Key?
finalinherited
onPressed → void Function(T? param)?
finalinherited
pressedBackgroundColor → Color?
final
pressedIconColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
size → Size
final
style → ButtonStyle?
final
text → String? Function(T? param)
finalinherited
tooltip → String? Function(T? param)
finalinherited
toolValue → ValueNotifier<T>?
finalinherited
visibility → ToolVisibility
finalinherited
width → double?
no setterinherited

Methods

build(BuildContext context, {EdgeInsets margin = const EdgeInsets.all(0), Axis orientation = Axis.horizontal, bool compact = false, bool floating = false}) → Widget
inherited
buildWidget(BuildContext context, {T? param, Axis orientation = Axis.horizontal, bool compact = false, bool floating = false, String? tooltip}) → Widget
override
calcSize(BuildContext context, {double spacing = 0, Axis orientation = Axis.horizontal, T? param}) → Size?
override
getToolContainerDecoration(BuildContext context) → Decoration?
inherited
getToolContainerPadding(BuildContext context) → EdgeInsets?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

styleFrom() → ButtonStyle