StatusTextTool<T extends Equatable> class

Inheritance

Constructors

StatusTextTool({Key? key, ToolVisibility visibility = ToolVisibility.showOnCompact, ValueNotifier<T>? toolValue, String? text(T? param) = _null<String>, String? tooltip(T? param) = _null<String>, TextStyle? style, bool embossed = false, Alignment alignment = Alignment.center, double width = 0, double height = 32, EdgeInsets padding = const EdgeInsets.fromLTRB(8, 2, 8, 2)})
const

Properties

alignment → Alignment?
no setteroverride
embossed → bool
final
enabled → bool Function(T? param)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
no setteroverride
hidden → bool Function(T? param)
finalinherited
icon → Widget? Function(T? param)
finalinherited
iconData → IconData? Function(T? param)
finalinherited
key → Key?
finalinherited
onPressed → void Function(T? param)?
finalinherited
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
final
text → String? Function(T? param)
finalinherited
tooltip → String? Function(T? param)
finalinherited
toolValue → ValueNotifier<T>?
finalinherited
visibility → ToolVisibility
finalinherited
width → double?
no setteroverride

Methods

build(BuildContext context, {EdgeInsets margin = const EdgeInsets.all(0), Axis orientation = Axis.horizontal, bool compact = false, bool floating = false}) → Widget
inherited
buildWidget(BuildContext context, {T? param, Axis orientation = Axis.horizontal, bool compact = false, bool floating = false, String? tooltip}) → Widget
override
calcSize(BuildContext context, {double spacing = 0, Axis orientation = Axis.horizontal, T? param}) → Size?
override
getToolContainerDecoration(BuildContext context) → Decoration?
override
getToolContainerPadding(BuildContext context) → EdgeInsets?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited