TextButtonTool<T> class

Inheritance

Constructors

TextButtonTool({Key? key, ToolVisibility visibility = ToolVisibility.showOnCompact, ValueNotifier<T>? toolValue, Widget? icon(T? param) = _null<Widget>, IconData? iconData(T? param) = _null<IconData>, String? text(T? param) = _null<String>, bool enabled(T? param) = _true, String? tooltip(T? param) = _null<String>, void onPressed(T? param)?, List<String>? options(T? param) = _null<List<String>>, OnOption? onOption, TextStyle? textStyle, bool textShadow = false, bool insetToolContainer = true, bool addPaddingForOptionsDropdown = true, bool alignDropdownToText = true, double? iconSize = 24, Color? iconColor, bool animateDown = true, double? fontSize, Color? fontColor, Alignment alignment = Alignment.center, double? width, double? height = 32, String? buttonSemanticsLabel, String? optionsSemanticsLabel, VoidCallback? onInit, VoidCallback? onDispose})
const
TextButtonTool.statusbar({Key? key, ToolVisibility visibility = ToolVisibility.showOnCompact, ValueNotifier<T>? toolValue, Widget? icon(T? param) = _null<Widget>, IconData? iconData(T? param) = _null<IconData>, String? text(T? param) = _null<String>, bool enabled(T? param) = _enabled, String? tooltip(T? param) = _null<String>, dynamic onPressed(T? param)?, List<String>? options(T? param) = _null<List<String>>, OnOption? onOption, TextStyle? textStyle, bool textShadow = false, bool alignDropdownToText = true, double iconSize = StatusViewBar.defaultIconSize, Color? iconColor, double fontSize = StatusViewBar.defaultFontSize, Color? fontColor, Alignment alignment = Alignment.center, double? width, double? height = StatusViewBar.defaultHeight, String? buttonSemanticsLabel, String? optionsSemanticsLabel, VoidCallback? onInit, VoidCallback? onDispose})
factory

Properties

addPaddingForOptionsDropdown → bool
final
alignDropdownToText → bool
final
alignment → Alignment?
no setteroverride
animateDown → bool
final
buttonSemanticsLabel → String?
final
enabled → bool Function(T? param)
finalinherited
fontColor → Color?
final
fontSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
no setteroverride
hidden → bool Function(T? param)
finalinherited
icon → Widget? Function(T? param)
finalinherited
iconColor → Color?
final
iconData → IconData? Function(T? param)
finalinherited
iconSize → double?
final
insetToolContainer → bool
final
key → Key?
finalinherited
onDispose → VoidCallback?
final
onInit → VoidCallback?
final
onOption → OnOption?
final
onPressed → void Function(T? param)?
finalinherited
options → List<String>? Function(T? param)
final
optionsSemanticsLabel → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String? Function(T? param)
finalinherited
textShadow → bool
final
textStyle → TextStyle?
final
tooltip → String? Function(T? param)
finalinherited
toolValue → ValueNotifier<T>?
finalinherited
visibility → ToolVisibility
finalinherited
width → double?
no setteroverride

Methods

build(BuildContext context, {EdgeInsets margin = const EdgeInsets.all(0), Axis orientation = Axis.horizontal, bool compact = false, bool floating = false}) → Widget
inherited
buildWidget(BuildContext context, {T? param, Axis orientation = Axis.horizontal, bool compact = false, bool floating = false, String? tooltip}) → Widget
override
calcSize(BuildContext context, {double spacing = 0, Axis orientation = Axis.horizontal, T? param}) → Size?
override
getToolContainerDecoration(BuildContext context) → Decoration?
override
getToolContainerPadding(BuildContext context) → EdgeInsets?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited