ToolGroup<T extends Equatable> class

Inheritance

Constructors

ToolGroup({Key? key, ValueNotifier<T>? toolValue, ToolVisibility visibility = ToolVisibility.always, required List<ToolBuilder<T>> tools})
const

Properties

alignment → Alignment?
no setterinherited
enabled → bool Function(T? param)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
no setterinherited
hidden → bool Function(T? param)
finalinherited
icon → Widget? Function(T? param)
finalinherited
iconData → IconData? Function(T? param)
finalinherited
key → Key?
finalinherited
onPressed → void Function(T? param)?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String? Function(T? param)
finalinherited
tools → List<ToolBuilder<T>>
final
tooltip → String? Function(T? param)
finalinherited
toolValue → ValueNotifier<T>?
finalinherited
visibility → ToolVisibility
finalinherited
width → double?
no setterinherited

Methods

build(BuildContext context, {EdgeInsets margin = const EdgeInsets.all(0), Axis orientation = Axis.horizontal, bool compact = false, bool floating = false}) → Widget
inherited
buildWidget(BuildContext context, {T? param, Axis orientation = Axis.horizontal, bool compact = false, bool floating = false, String? tooltip}) → Widget
override
calcSize(BuildContext context, {double spacing = 0, Axis orientation = Axis.horizontal, T? param}) → Size?
override
getToolContainerDecoration(BuildContext context) → Decoration?
inherited
getToolContainerPadding(BuildContext context) → EdgeInsets?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited