TabItem class

Tab info that hold the title widget and tab color.

Constructors

TabItem({required Color color, required Widget title, Color? unselectedColor, Color? labelColor, Color? unselectedLabelColor, TextStyle? labelStyle, TextStyle? unselectedLabelStyle})

Properties

color → Color
tab color, must be non-null
final
hashCode → int
The hash code for this object.
no setterinherited
labelColor → Color?
The color of the selected tab label.
final
labelStyle → TextStyle?
The text style of the selected tab labels.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → Widget
tab Widget, typical Text(), must be non-null
final
unSelectedColor → Color
tab color when unselected
final
unselectedLabelColor → Color?
The color of unselected tab label.
final
unselectedLabelStyle → TextStyle?
The text style of the unselected tab labels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited